@@ -18,6 +18,7 @@ import (
 	"github.com/charmbracelet/bubbles/paginator"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/lipgloss"
+	"github.com/charmbracelet/x/exp/ordered"
 )
 
 func defaultKeymap() keymap {
@@ -97,6 +98,7 @@ func (k keymap) ShortHelp() []key.Binding {
 
 type model struct {
 	height           int
+	padding          []int
 	cursor           string
 	selectedPrefix   string
 	unselectedPrefix string
@@ -157,10 +159,10 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				m.paginator.PrevPage()
 			}
 		case key.Matches(msg, km.Right):
-			m.index = clamp(m.index+m.height, 0, len(m.items)-1)
+			m.index = ordered.Clamp(m.index+m.height, 0, len(m.items)-1)
 			m.paginator.NextPage()
 		case key.Matches(msg, km.Left):
-			m.index = clamp(m.index-m.height, 0, len(m.items)-1)
+			m.index = ordered.Clamp(m.index-m.height, 0, len(m.items)-1)
 			m.paginator.PrevPage()
 		case key.Matches(msg, km.End):
 			m.index = len(m.items) - 1
@@ -277,18 +279,11 @@ func (m model) View() string {
 	}
 	parts = append(parts, s.String())
 	if m.showHelp {
-		parts = append(parts, m.help.View(m.keymap))
+		parts = append(parts, "", m.help.View(m.keymap))
 	}
 
-	return lipgloss.JoinVertical(lipgloss.Left, parts...)
-}
-
-func clamp(x, low, high int) int {
-	if x < low {
-		return low
-	}
-	if x > high {
-		return high
-	}
-	return x
+	view := lipgloss.JoinVertical(lipgloss.Left, parts...)
+	return lipgloss.NewStyle().
+		Padding(m.padding...).
+		Render(view)
 }
