@@ -4,9 +4,11 @@ import (
 	"fmt"
 	"regexp"
 
+	"github.com/charmbracelet/bubbles/help"
 	"github.com/charmbracelet/bubbles/viewport"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/gum/internal/stdin"
+	"github.com/charmbracelet/gum/internal/timeout"
 )
 
 // Run provides a shell script interface for the viewport bubble.
@@ -29,9 +31,9 @@ func (o Options) Run() error {
 		}
 	}
 
-	model := model{
+	m := model{
 		viewport:            vp,
-		helpStyle:           o.HelpStyle.ToLipgloss(),
+		help:                help.New(),
 		content:             o.Content,
 		origContent:         o.Content,
 		showLineNumbers:     o.ShowLineNumbers,
@@ -39,12 +41,21 @@ func (o Options) Run() error {
 		softWrap:            o.SoftWrap,
 		matchStyle:          o.MatchStyle.ToLipgloss(),
 		matchHighlightStyle: o.MatchHighlightStyle.ToLipgloss(),
-		timeout:             o.Timeout,
-		hasTimeout:          o.Timeout > 0,
+		keymap:              defaultKeymap(),
 	}
-	_, err := tea.NewProgram(model, tea.WithAltScreen()).Run()
+
+	ctx, cancel := timeout.Context(o.Timeout)
+	defer cancel()
+
+	_, err := tea.NewProgram(
+		m,
+		tea.WithAltScreen(),
+		tea.WithReportFocus(),
+		tea.WithContext(ctx),
+	).Run()
 	if err != nil {
 		return fmt.Errorf("unable to start program: %w", err)
 	}
+
 	return nil
 }
